changeset 14327:c09d6af75fd9

Merge
author fparain
date Thu, 06 Feb 2014 14:51:01 -0500
parents 4f0acb75c921 (diff) e7d8cbe4db3b (current diff)
children 260ff1b76790
files
diffstat 1 files changed, 3 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/test/runtime/RedefineObject/Agent.java	Thu Feb 06 17:59:35 2014 +0000
+++ b/test/runtime/RedefineObject/Agent.java	Thu Feb 06 14:51:01 2014 -0500
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2013, 2014, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -65,8 +65,8 @@
     public static void main(String[] args) {
         byte[] ba = new byte[0];
 
-        // If it survives 1000 GC's, it's good.
-        for (int i = 0; i < 1000 ; i++) {
+        // If it survives 100 GC's, it's good.
+        for (int i = 0; i < 100 ; i++) {
             System.gc();
             ba.clone();
         }